summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_support.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_support.py')
-rw-r--r--Lib/test/test_support.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/Lib/test/test_support.py b/Lib/test/test_support.py
index e60e547..9a3cf14 100644
--- a/Lib/test/test_support.py
+++ b/Lib/test/test_support.py
@@ -548,13 +548,14 @@ class TestSupport(unittest.TestCase):
with self.subTest(opts=opts):
self.check_options(opts, 'optim_args_from_interpreter_flags')
+ @unittest.skipIf(support.is_apple_mobile, "Unstable on Apple Mobile")
@unittest.skipIf(support.is_emscripten, "Unstable in Emscripten")
@unittest.skipIf(support.is_wasi, "Unavailable on WASI")
def test_fd_count(self):
# We cannot test the absolute value of fd_count(): on old Linux
# kernel or glibc versions, os.urandom() keeps a FD open on
# /dev/urandom device and Python has 4 FD opens instead of 3.
# Test is unstable on Emscripten. The platform starts and stops
# background threads that use pipes and epoll fds.
start = os_helper.fd_count()
fd = os.open(__file__, os.O_RDONLY)
@@ -548,13 +548,14 @@ class TestSupport(unittest.TestCase):
def test_fd_count(self):
- # We cannot test the absolute value of fd_count(): on old Linux
- # kernel or glibc versions, os.urandom() keeps a FD open on
- # /dev/urandom device and Python has 4 FD opens instead of 3.
- # Test is unstable on Emscripten. The platform starts and stops
+ # We cannot test the absolute value of fd_count(): on old Linux kernel
+ # or glibc versions, os.urandom() keeps a FD open on /dev/urandom
+ # device and Python has 4 FD opens instead of 3. Test is unstable on
+ # Emscripten and Apple Mobile platforms; these platforms start and stop
# background threads that use pipes and epoll fds.
start = os_helper.fd_count()